@@ -447,7 +447,7 @@ def __minify_js(in_file, out_file, verbose, strict=False):
                '--js_output_file %s' % out_file,
                '--warning_level QUIET']
 
-    if strict:
+    if strict == True:
         options.append('--language_in=ECMASCRIPT5_STRICT')
 
     os.system('java -jar "%s" %s' % (JS_COMPRESSOR,
